@@ -1,9 +1,7 @@
 package Dist::Zilla::MintingProfile::Author::YANICK;
-BEGIN {
-  $Dist::Zilla::MintingProfile::Author::YANICK::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: create distributions like YANICK
-$Dist::Zilla::MintingProfile::Author::YANICK::VERSION = '0.22.1';
+$Dist::Zilla::MintingProfile::Author::YANICK::VERSION = '0.23.0';
 use strict;
 use warnings;
 
@@ -27,7 +25,7 @@ Dist::Zilla::MintingProfile::Author::YANICK - create distributions like YANICK
 
 =head1 VERSION
 
-version 0.22.1
+version 0.23.0
 
 =head1 AUTHOR
 
