@@ -1,9 +1,7 @@
 package Dist::Zilla::Plugin::Author::YANICK::NextSemanticVersion;
-BEGIN {
-  $Dist::Zilla::Plugin::Author::YANICK::NextSemanticVersion::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: update the next version, semantic-wise
-$Dist::Zilla::Plugin::Author::YANICK::NextSemanticVersion::VERSION = '0.22.1';
+$Dist::Zilla::Plugin::Author::YANICK::NextSemanticVersion::VERSION = '0.23.0';
 use strict;
 use warnings;
 
@@ -175,7 +173,7 @@ Dist::Zilla::Plugin::Author::YANICK::NextSemanticVersion - update the next versi
 
 =head1 VERSION
 
-version 0.22.1
+version 0.23.0
 
 =head1 AUTHOR
 
