@@ -1,8 +1,6 @@
 package Dist::Zilla::PluginBundle::YANICK;
-BEGIN {
-  $Dist::Zilla::PluginBundle::YANICK::AUTHORITY = 'cpan:YANICK';
-}
-$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.22.1';
+our $AUTHORITY = 'cpan:YANICK';
+$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.23.0';
 # ABSTRACT: Be like Yanick when you build your dists
 
 # [TODO] add CONTRIBUTING file
@@ -83,7 +81,7 @@ sub configure {
           [ Authority => { 
             ( authority => $arg->{authority} ) x !!$arg->{authority}  
           } ],
-          qw/ ReportVersions::Tiny
+          qw/ Test::ReportPrereqs
           Signature /,
           [ AutoPrereqs => { 
                   ( skip => $arg->{autoprereqs_skip} ) 
@@ -185,7 +183,7 @@ Dist::Zilla::PluginBundle::YANICK - Be like Yanick when you build your dists
 
 =head1 VERSION
 
-version 0.22.1
+version 0.23.0
 
 =head1 DESCRIPTION
 
@@ -235,7 +233,7 @@ his distributions. It's roughly equivalent to
     [PkgVersion]
     [Authority]
 
-    [ReportVersions::Tiny]
+    [Test::ReportPrereqs]
     [Signature]
 
     [AutoPrereqs]
